"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.splitLib = void 0;
const schematics_1 = require("@angular-devkit/schematics");
const index_1 = require("../subentry/index");
const path_helper_1 = require("../shared/path-helper");
const add_tsconfig_paths_rule_1 = require("../rules/add-tsconfig-paths.rule");
const update_import_paths_rule_1 = require("../rules/update-import-paths.rule");
const update_subentry_public_api_rule_1 = require("../rules/update-public-api/update-subentry-public-api.rule");
const update_top_level_public_api_rule_1 = require("../rules/update-public-api/update-top-level-public-api.rule");
const log_helper_1 = require("../shared/log-helper");
function splitLib(_options) {
    (0, log_helper_1.logWelcomeMessage)();
    return (tree, _context) => {
        const libRootPath = (0, path_helper_1.getLibRootPath)(tree);
        const rules = [];
        const modulePaths = [];
        tree.getDir(libRootPath).visit(filePath => {
            if (filePath.endsWith('.ts')) {
                rules.push((0, update_import_paths_rule_1.updateImportPaths)(filePath));
            }
            if (filePath.endsWith('module.ts')) {
                modulePaths.push(filePath);
                rules.push((0, index_1.generateSubentry)({
                    name: (0, path_helper_1.getModuleName)(filePath),
                    filesPath: '../subentry/files',
                    path: (0, path_helper_1.resolvePath)((0, path_helper_1.getFolderPath)(filePath), '..'),
                    generateComponent: false,
                    generateModule: false
                }));
                rules.push((0, update_subentry_public_api_rule_1.updateSubentryPublicAPI)(filePath));
            }
        });
        rules.push((0, update_top_level_public_api_rule_1.updateTopLevelPublicAPI)(modulePaths));
        rules.push((0, add_tsconfig_paths_rule_1.addTsconfigPaths)());
        return (0, schematics_1.chain)(rules);
    };
}
exports.splitLib = splitLib;
//# sourceMappingURL=index.js.map