"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.addTsconfigPaths = void 0;
const log_helper_1 = require("../shared/log-helper");
function addTsconfigPaths() {
    return (tree) => {
        try {
            // While reading the tsconfig, use a regex replacement https://www.regextester.com/94245
            // to ensure no **JSON comments** are present. Comments lead to a JSON.parse error.
            const tsconfig = JSON.parse(tree
                .read('tsconfig.json')
                .toString()
                .replace(/\/\*[\s\S]*?\*\/|([^:]|^)\/\/.*$/gm, ''));
            const angularJSON = JSON.parse(tree.read('angular.json').toString());
            const libraryProjectNames = getLibraryProjectNames(angularJSON);
            if (!tsconfig.compilerOptions.paths) {
                tsconfig.compilerOptions.paths = {};
            }
            libraryProjectNames.forEach((libraryProjectName) => {
                tsconfig.compilerOptions.paths[`${libraryProjectName}/*`] = [
                    `projects/${libraryProjectName}/*`,
                    `projects/${libraryProjectName}`
                ];
            });
            tree.overwrite('tsconfig.json', JSON.stringify(tsconfig, null, 2));
        }
        catch (e) {
            (0, log_helper_1.logError)(`Something went wrong while ng-samurai tried to update your tsconfig.json, ${e.toString()}`);
        }
    };
}
exports.addTsconfigPaths = addTsconfigPaths;
function getLibraryProjectNames(angularJSON) {
    return Object.values(angularJSON.projects)
        .filter((project) => project.projectType === 'library')
        .map((project) => project.root.split('/')[1]);
}
//# sourceMappingURL=add-tsconfig-paths.rule.js.map